@@ -1,10 +1,16 @@
-import argparse
+from __future__ import annotations
+
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from pdm.cli.commands.base import BaseCommand
 from pdm.cli.commands.venv.utils import iter_venvs
 from pdm.cli.options import verbose_option
-from pdm.project import Project
+
+if TYPE_CHECKING:
+    from argparse import Namespace
+
+    from pdm.project import Project
 
 
 class ListCommand(BaseCommand):
@@ -12,12 +18,9 @@ class ListCommand(BaseCommand):
 
     arguments = (verbose_option,)
 
-    def handle(self, project: Project, options: argparse.Namespace) -> None:
+    def handle(self, project: Project, options: Namespace) -> None:
         project.core.ui.echo("Virtualenvs created with this project:\n")
+        saved_python_root = Path(saved_python).parent.parent if (saved_python := project._saved_python) else None
         for ident, venv in iter_venvs(project):
-            saved_python = project._saved_python
-            if saved_python and Path(saved_python).parent.parent == venv.root:
-                mark = "*"
-            else:
-                mark = "-"
+            mark = "*" if saved_python_root and saved_python_root == venv.root else "-"
             project.core.ui.echo(f"{mark}  [success]{ident}[/]: {venv.root}")
